==> group_subscription-2.0.0-alpha3.tar.gz: group_subscription/src/Plugin/QueueWorker/ImmediateAnnouncementBase.php <==
<?php

/**
 * @file
 * Contains Drupal\group_subscription\Plugin\QueueWorker\ImmediateAnnouncementBase.php
 */

namespace Drupal\group_subscription\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\Mail\MailManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Render\RendererInterface;

/**
 * Provides base functionality for the Announcement Immediate Email Queue Workers.
 */
abstract class ImmediateAnnouncementBase extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
  * The mail manager.
  *
  * @var Drupal\Core\Mail\MailManager
  */
  protected $mail;

  /**
   * The user storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $userStorage;

  /**
   * The node storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * The theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected $themeManager;

  /**
   * The renderer.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * {@inheritdoc}
   */
  public function __construct(
      MailManager $mail,
      EntityStorageInterface $user_storage,
      EntityStorageInterface $node_storage,
      ThemeManagerInterface $theme_manager,
      RendererInterface $renderer
  ) {
    $this->mail = $mail;
    $this->userStorage = $user_storage;
    $this->nodeStorage = $node_storage;
    $this->themeManager = $theme_manager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $container->get('plugin.manager.mail'),
      $container->get('entity.manager')->getStorage('user'),
      $container->get('entity.manager')->getStorage('node'),
      $container->get('theme.manager'),
      $container->get('renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $protoemail = $data;

    // Check the master switch, sitewide setting and account status for the recipient.
    $query = \Drupal::database()->select('group_subscription_global', 'g');
    $query->join('users_field_data', 'f', 'g.uid = f.uid');
    $query->fields('g', ['uid'])
      ->condition('g.uid', $protoemail->uid)
      ->condition('g.status', 1)
      ->condition('g.sitewide', 1)
      ->condition('f.status', 1);

    $user = $query->execute()->fetchField();
    if ($user) {
      // Build and send this email.
      $this->sendImmediateEmail($protoemail);
    }

  }

  /**
   * Convert this protoemail into an actual email message and send it.
   *
   * @return int
   */
  protected function sendImmediateEmail($protoemail) {
    $params = [];

    // Load the subscribed user object to serve as the email recipient.
    $uid = $protoemail->uid;
    $user = $this->userStorage->load($uid);

    // User values for email settings.
    $email = $user->getEmail();
    $username = $user->getDisplayName();
    $langcode = $user->getPreferredLangcode();

    // Set recipient display name.
    $params['recipient'] = $username;

    // Get entity information so we can determine how to load the entity.
    $entityid = $protoemail->entityid;
    $entitytype = $protoemail->entitytype;
    $bundle = $protoemail->bundle;

    // Determine which theme we should use to render these items.
    $config = \Drupal::config('system.theme');
    $default_theme = $config->get('default');
    $this->themeManager->setActiveTheme(\Drupal::service('theme.initialization')->initTheme($default_theme));

    // Build the email based on the type of entity we're working with.
    if ($entitytype === 'node') {
      $entity = $this->nodeStorage->load($entityid);
      if (is_null($entity)) {
        // This entity does not exist.
        return;
      }
      $author = $entity->getOwner();

      // Add email subject line.
      $params['subject'] = t('New Announcement: @title by @author',
        ['@title' => $entity->getTitle(),
          '@author' => $author->getDisplayName(),
        ]);

      $params['author'] = $author->getDisplayName();

      // Render the content using group_subscription_announcement display.
      $content = \Drupal::entityTypeManager()
        ->getViewBuilder($entity->getEntityTypeId())
        ->view($entity, 'group_subscription_announcement');
      $params['content'] = $this->renderer->renderRoot($content);
      // TODO: fix to use proper dependency injection.

      $params['link'] = $entity
        ->toLink(NULL, 'canonical', ['absolute' => TRUE])
        ->setText(t('View Announcement'))
        ->toString();

      // See hook_mail() implementation in group_subscription.module.
      $this->mail->mail(
        'group_subscription',
        'announcement',
        $email,
        $langcode ?: 'en',
        $params,
        NULL,
        TRUE
      );

    }
    else {
      // TODO: something strange is afoot track error.
      return;
    }

  }

}

==> group_subscription-3.0.0-alpha3.tar.gz: group_subscription/src/Plugin/QueueWorker/ImmediateAnnouncementBase.php <==
<?php

namespace Drupal\group_subscription\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\Mail\MailManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Provides base functionality for the Announcement Immediate Email Queue Workers.
 */
abstract class ImmediateAnnouncementBase extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The mail manager.
   *
   * @var Drupal\Core\Mail\MailManager
   */
  protected $mail;

  /**
   * The user storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $userStorage;

  /**
   * The node storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * The theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected $themeManager;

  /**
   * The renderer.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * {@inheritdoc}
   */
  public function __construct(
      MailManager $mail,
      EntityStorageInterface $user_storage,
      EntityStorageInterface $node_storage,
      ThemeManagerInterface $theme_manager,
      RendererInterface $renderer
  ) {
    $this->mail = $mail;
    $this->userStorage = $user_storage;
    $this->nodeStorage = $node_storage;
    $this->themeManager = $theme_manager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $container->get('plugin.manager.mail'),
      $container->get('entity_type.manager')->getStorage('user'),
      $container->get('entity_type.manager')->getStorage('node'),
      $container->get('theme.manager'),
      $container->get('renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $protoemail = $data;

    // Check subscription settings and account status for the recipient.
    $query = \Drupal::database()->select('group_subscription_global', 'g');
    $query->join('users_field_data', 'f', 'g.uid = f.uid');
    $query->fields('g', ['uid'])
      ->condition('g.uid', $protoemail->uid)
      ->condition('g.status', 1)
      ->condition('g.sitewide', 1)
      ->condition('f.status', 1);

    $user = $query->execute()->fetchField();
    if ($user) {
      // Build and send this email.
      $this->sendImmediateEmail($protoemail);
    }

  }

  /**
   * Convert this protoemail into an actual email message and send it.
   */
  protected function sendImmediateEmail($protoemail) {
    $params = [];

    // Load the subscribed user object to serve as the email recipient.
    $uid = $protoemail->uid;
    $user = $this->userStorage->load($uid);

    // User values for email settings.
    $email = $user->getEmail();
    $username = $user->getDisplayName();
    $langcode = $user->getPreferredLangcode();

    // Set recipient display name.
    $params['recipient'] = $username;

    // Get entity information so we can determine how to load the entity.
    $entityid = $protoemail->entityid;
    $entitytype = $protoemail->entitytype;
    $bundle = $protoemail->bundle;

    // Determine which theme we should use to render these items.
    $config = \Drupal::config('system.theme');
    $default_theme = $config->get('default');
    $this->themeManager->setActiveTheme(\Drupal::service('theme.initialization')->initTheme($default_theme));

    // Build the email based on the type of entity we're working with.
    if ($entitytype === 'node') {
      $entity = $this->nodeStorage->load($entityid);
      if (is_null($entity)) {
        // This entity does not exist.
        return;
      }
      $author = $entity->getOwner();

      // Add email subject line.
      $params['subject'] = $this->t('New Announcement: @title by @author',
        [
          '@title' => $entity->getTitle(),
          '@author' => $author->getDisplayName(),
        ]);

      $params['author'] = $author->getDisplayName();

      // Render the content using group_subscription_announcement display.
      // TODO: fix to use proper dependency injection.
      $content = \Drupal::entityTypeManager()
        ->getViewBuilder($entity->getEntityTypeId())
        ->view($entity, 'group_subscription_announcement');
      $params['content'] = $this->renderer->renderRoot($content);

      $params['link'] = $entity
        ->toLink(NULL, 'canonical', ['absolute' => TRUE])
        ->setText($this->t('View Announcement'))
        ->toString();

      // See hook_mail() implementation in group_subscription.module.
      $this->mail->mail(
        'group_subscription',
        'announcement',
        $email,
        $langcode ?: 'en',
        $params,
        NULL,
        TRUE
      );

    }
    else {
      // TODO: something strange is afoot track error.
      return;
    }

  }

}
